<?php
/**
 * Plugin Name:       Custom Content Blocks
 * Description:       Collection custom blocks.
 * Requires at least: 5.7
 * Requires PHP:      5.6
 * Version:           0.1.85
 * Author:            Alex Lundin
 * License:           GPL-2.0-or-later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       asl-blocks
 *
 * @package           asl-blocks
 */

defined( 'ABSPATH' ) || exit;


add_action( 'wp_enqueue_scripts', 'asl_theme_add_scripts' );
function asl_theme_add_scripts() {
	wp_enqueue_script( 'asl_product-animate', plugins_url( 'blocks/product/assets/js/animate.js', __FILE__ ), array(), null, true );
	wp_enqueue_style( 'asl_product-animate', plugins_url( 'blocks/product/assets/css/animate.css', __FILE__ ) );
	wp_enqueue_style( 'asl_product-color', plugins_url( 'style.css', __FILE__ ) );
}

if ( (double) $wp_version >= 5.8 ) {
	function asl_new_category( $categories, $post ) {
		return array_merge(
			$categories,
			array(
				array(
					'slug'  => 'block-by-asl',
					'title' => __( 'Blocks by Alex Lundin', 'asl-blocks' ),
				),
			)
		);
	}

	add_filter( 'block_categories_all', 'asl_new_category', 10, 2 );
} else {
	add_filter( 'block_categories', 'custom_block_category', 10, 2 );

	function custom_block_category( $default_categories, $post ) {

		if ( $post->post_type !== 'post' ) {
			return $default_categories;
		}

		return array_merge(
			$default_categories,
			[
				[
					'slug'  => 'block-by-asl',
					'title' => __( 'Blocks by Alex Lundin', 'asl-blocks' ),
				],
			]
		);

	}
}
add_filter( 'body_class', 'asl_blocks_add_body_classes' );
function asl_blocks_add_body_classes( $classes ) {
	$classes[] = 'asl-blocks';

	return $classes;
}

include 'blocks/asl-button/asl-button.php';
include 'blocks/asl-advantage-table/asl-advantage-table.php';
include 'blocks/cta-1/cta-1.php';
include 'blocks/cta-2/cta-2.php';
include 'blocks/product/product.php';
include 'blocks/product-row/product-row.php';
include 'blocks/product-table/product-table.php';

function asl_gutenberg_default_colors() {
	$my_colors = [
		[
			'name'  => 'Purple',
			'slug'  => 'purple',
			'color' => '#332e54'
		],
		[
			'name'  => 'Orange',
			'slug'  => 'orange',
			'color' => '#f7882f'
		],
		[
			'name'  => 'Black',
			'slug'  => 'black',
			'color' => '#000000'
		],
		[
			'name'  => 'Gray',
			'slug'  => 'gray',
			'color' => '#f4f4f4'
		],
		[
			'name'  => 'Red',
			'slug'  => 'red',
			'color' => '#ef3737'
		],
		[
			'name'  => 'Red Light',
			'slug'  => 'red-light',
			'color' => '#fa5d49'
		],
		[
			'name'  => 'Red Dark',
			'slug'  => 'red-dark',
			'color' => '#aa0511'
		],
	];

	add_theme_support(
		'editor-color-palette',
		$my_colors
	);

}

add_action( 'init', 'asl_gutenberg_default_colors' );

