/**
 * Registers a new block provided a unique name and an object defining its behavior.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-registration/
 */
import { registerBlockType } from '@wordpress/blocks';

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * All files containing `style` keyword are bundled together. The code used
 * gets applied both to the front of your site and to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import './style.scss';

/**
 * Internal dependencies
 */
import Edit from './edit';
import save from './save';

/**
 * Every block starts by registering a new block type definition.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-registration/
 */
registerBlockType('asl/asl-advantage-table', {
	icon: {
		foreground: '#7e70af',
		src: (
			<svg
				id="Layer"
				height="512"
				viewBox="0 0 64 64"
				width="512"
				xmlns="http://www.w3.org/2000/svg"
			>
				<path d="m50 8h-36c-3.309 0-6 2.691-6 6v36c0 3.309 2.691 6 6 6h36c3.309 0 6-2.691 6-6v-36c0-3.309-2.691-6-6-6zm-24 29v-11h12v11zm12 4v11h-12v-11zm-26-15h10v11h-10zm30 0h10v11h-10zm-28-14h36c1.103 0 2 .897 2 2v8h-40v-8c0-1.103.897-2 2-2zm-2 38v-9h10v11h-8c-1.103 0-2-.897-2-2zm38 2h-8v-11h10v9c0 1.103-.897 2-2 2z" />
			</svg>
		),
	},
	attributes: {
		plusHead: {
			type: 'string',
			source: 'html',
			selector: '.plus span',
		},
		minusHead: {
			type: 'string',
			source: 'html',
			selector: '.minus span',
		},
		plusBody: {
			type: 'array',
			source: 'children',
			selector: '.plus-text ul',
		},
		minusBody: {
			type: 'array',
			source: 'children',
			selector: '.minus-text ul',
		},
		grayBody: {
			type: 'array',
			source: 'children',
			selector: '.gray_table div',
		},
	},
	/**
	 * @see ./edit.js
	 */
	edit: Edit,

	/**
	 * @see ./save.js
	 */
	save,
});
