/**
 * Retrieves the translation of text.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-i18n/
 */
import { __ } from '@wordpress/i18n';

/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
import { useBlockProps, RichText } from '@wordpress/block-editor';

/**
 * The save function defines the way in which the different attributes should
 * be combined into the final markup, which is then serialized by the block
 * editor into `post_content`.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#save
 *
 * @return {WPElement} Element to render.
 */

export default function save({ attributes }) {
	const blockProps = useBlockProps.save({
		className: 'asl_custom_t',
	});

	const { plusHead, minusHead, plusBody, minusBody, grayBody } = attributes;

	return (
		<table width="100%" {...blockProps}>
			<tbody>
				<tr>
					<td className="plus">
						<h3>
							<i role="img">✅</i>
							<RichText.Content tagName="span" value={plusHead} />
						</h3>
						<div className="plus-text">
							<RichText.Content
								tagName="ul"
								multiline="li"
								value={plusBody}
							/>
						</div>
					</td>
					<td className="minus">
						<h3>
							<i role="img" >⛔</i>
							<RichText.Content
								tagName="span"
								value={minusHead}
							/>
						</h3>
						<div className="minus-text">
							<RichText.Content
								tagName="ul"
								multiline="li"
								value={minusBody}
							/>
						</div>
					</td>
				</tr>
				<tr className="gray_table">
					<td colSpan="2">
						<RichText.Content
							tagName="div"
							// multiline="p"
							value={grayBody}
						/>
					</td>
				</tr>
			</tbody>
		</table>
	);
}
