/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
import { useBlockProps, InnerBlocks, RichText } from '@wordpress/block-editor';

/**
 * The save function defines the way in which the different attributes should
 * be combined into the final markup, which is then serialized by the block
 * editor into `post_content`.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#save
 *
 * @return {WPElement} Element to render.
 */
export default function save({ attributes }) {
	const {
		title,
		body,
		alignment,
		borderColor,
		borderWidth,
		borderRadius,
		btnText1,
		btnText2,
		btnStyleFirst,
		btnStyleSecond,
		btnBackgroundFirst,
		btnBackgroundSecond,
		borderRadiusFirst,
		borderRadiusSecond,
		borderWidthFirst,
		borderWidthSecond,
		btnBorderColorFirst,
		btnBorderColorSecond,
		btnLinkFirst,
		btnLinkSecond,
		btnColorFirst,
		btnColorSecond,
		rel,
		target,
	} = attributes;

	const blockProps = useBlockProps.save({
		className: 'asl-cta-1',
	});
	return (
		<div
			{...blockProps}
			style={{
				borderColor,
				borderWidth,
				borderRadius,
			}}
		>
			<InnerBlocks.Content />
			<h3 style={{ textAlign: alignment }}>{title}</h3>
			<div className="asl-cta-1-buttons">
				<RichText.Content
					tagName="a"
					value={btnText1}
					style={
						btnStyleFirst === 'fill'
							? {
									color: btnColorFirst,
									backgroundColor: btnBackgroundFirst,
									borderRadius: borderRadiusFirst,
							  }
							: {
									borderWidth: borderWidthFirst,
									borderColor: btnBorderColorFirst,
									borderStyle: 'solid',
									color: btnColorFirst,
									borderRadius: borderRadiusFirst,
							  }
					}
					target={target === true ? '_blank' : '_self'}
					href={btnLinkFirst}
					rel={rel}
					className={
						btnStyleFirst === 'fill'
							? 'asl-btn-cta-1 asl-btn-first asl-fill'
							: 'asl-btn-cta-1 asl-btn-first asl-outline'
					}
				/>
				<RichText.Content
					tagName="a"
					value={btnText2}
					style={
						btnStyleSecond === 'fill'
							? {
									color: btnColorSecond,
									backgroundColor: btnBackgroundSecond,
									borderRadius: borderRadiusSecond,
							  }
							: {
									borderWidth: borderWidthSecond,
									borderColor: btnBorderColorSecond,
									borderStyle: 'solid',
									color: btnColorSecond,
									borderRadius: borderRadiusSecond,
							  }
					}
					target={target === true ? '_blank' : '_self'}
					href={btnLinkSecond}
					rel={rel}
					className={
						btnStyleSecond === 'fill'
							? 'asl-btn-cta-1 asl-btn-second asl-fill'
							: 'asl-btn-cta-1 asl-btn-second asl-outline'
					}
				/>
			</div>
			<RichText.Content
				tagName="div"
				className="asl-cta-1-content"
				value={body}
			/>
		</div>
	);
}
