/**
 * Registers a new block provided a unique name and an object defining its behavior.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-registration/
 */
import { registerBlockType } from '@wordpress/blocks';

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * All files containing `style` keyword are bundled together. The code used
 * gets applied both to the front of your site and to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import './style.scss';

/**
 * Internal dependencies
 */
import Edit from './edit';
import save from './save';

/**
 * Every block starts by registering a new block type definition.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-registration/
 */
registerBlockType( 'asl/cta-2', {
	icon: {
		foreground: '#7e70af',
		src: (
			<svg xmlns="http://www.w3.org/2000/svg">
				<g>
					<rect fill="none" height="24" width="24" x="0" />
				</g>
				<g>
					<g>
						<path d="M3,5v14c0,1.1,0.89,2,2,2h6V3H5C3.89,3,3,3.9,3,5z M19,3h-6v8h8V5C21,3.9,20.1,3,19,3z M13,21h6c1.1,0,2-0.9,2-2v-6h-8V21 z" />
					</g>
				</g>
			</svg>
		),
	},
	example: {
		attributes: {
			body: [
				"<p>It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of using Lorem Ipsum is that it has a more-or-less normal distribution of letters, as opposed to using 'Content here, content here', making it look like readable English.</p>",
			],
			image: 'https://via.placeholder.com/150',
			backgroundColor: '#f4f4f4',
			width: 150,
		},
	},
	attributes: {
		body: {
			type: 'array',
			source: 'children',
			selector: '.asl-cta-2-text',
		},
		backgroundColor: {
			type: 'string',
			default: '#f4f4f4',
		},
		btnText: {
			type: 'string',
			default: '',
			source: 'html',
			selector: '.asl-btn-cta-2',
		},
		btnStyle: {
			type: 'string',
			default: 'outline',
		},
		btnBackground: {
			type: 'string',
			default: '',
		},
		btnColor: {
			type: 'string',
			default: '',
		},
		btnBorderRadius: {
			type: 'number',
			default: 1,
		},
		btnBorderWidth: {
			type: 'number',
			default: 2,
		},
		btnBorderColor: {
			type: 'string',
			default: '',
		},
		btnLink: {
			type: 'string',
			source: 'attribute',
			selector: '.asl-btn-cta-2',
			attribute: 'href',
		},
		rel: {
			type: 'string',
			source: 'attribute',
			selector: 'a',
			attribute: 'rel',
			default: 'sponsored nofollow',
		},
		target: {
			type: 'boolean',
			default: false,
		},
	},

	/**
	 * @see ./edit.js
	 */
	edit: Edit,

	/**
	 * @see ./save.js
	 */
	save,
} );
