/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
import { useBlockProps, RichText, InnerBlocks } from '@wordpress/block-editor';

/**
 * The save function defines the way in which the different attributes should
 * be combined into the final markup, which is then serialized by the block
 * editor into `post_content`.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#save
 *
 * @return {WPElement} Element to render.
 */
export default function save( { attributes } ) {
	const {
		body,
		backgroundColor,
		btnText,
		btnStyle,
		btnBackground,
		btnColor,
		btnBorderRadius,
		btnBorderWidth,
		btnBorderColor,
		btnLink,
		rel,
		target,
	} = attributes;

	const blockProps = useBlockProps.save( {
		className: 'asl-cta-2',
	} );

	return (
		<div { ...blockProps } style={ { backgroundColor } }>
			<div className="asl-cta-2-image">
				<InnerBlocks.Content />
			</div>
			<div>
				<RichText.Content
					tagName="div"
					className="asl-cta-2-text"
					value={ body }
				/>

				<div
					className="asl-cta-2-buttons"
					style={ { textAlign: 'center' } }
				>
					<RichText.Content
						tagName="a"
						value={ btnText }
						style={
							btnStyle === 'fill'
								? {
										color: btnColor,
										backgroundColor: btnBackground,
										borderRadius: btnBorderRadius,
								  }
								: {
										borderWidth: btnBorderWidth,
										borderColor: btnBorderColor,
										borderStyle: 'solid',
										color: btnColor,
										borderRadius: btnBorderRadius,
								  }
						}
						target={ target === true ? '_blank' : '_self' }
						href={ btnLink }
						rel={ rel }
						className={
							btnStyle === 'fill'
								? 'asl-btn-cta-2 asl-fill'
								: 'asl-btn-cta-2 asl-outline'
						}
					/>
				</div>
			</div>
		</div>
	);
}
