/**
 * Registers a new block provided a unique name and an object defining its behavior.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-registration/
 */
import { registerBlockType } from '@wordpress/blocks';

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * All files containing `style` keyword are bundled together. The code used
 * gets applied both to the front of your site and to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import './style.scss';

/**
 * Internal dependencies
 */
import Edit from './edit';
import save from './save';

/**
 * Every block starts by registering a new block type definition.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-registration/
 */
registerBlockType( 'asl/product-row', {
	attributes: {
		number: {
			type: 'string',
			source: 'text',
			selector: '.asl-table-number',
		},
		heading: {
			type: 'string',
			source: 'text',
			selector: '.asl-product-heading',
		},
		postList: {
			source: 'html',
			multiline: 'li',
			selector: '.asl-product-table__list',
		},
		label: {
			type: 'string',
			source: 'text',
			selector: '.asl-table-label',
		},
		btnText: {
			type: 'string',
			source: 'text',
			selector: '.asl-btn-pt',
		},
		link: {
			type: 'string',
			source: 'attribute',
			attribute: 'href',
			selector: 'a',
			default: '',
		},
		btnBackground: {
			type: 'string',
			default: '#DD3333',
		},
		btnColor: {
			type: 'string',
			default: '#fff',
		},
		rel: {
			type: 'string',
			source: 'attribute',
			attribute: 'rel',
			selector: 'a',
			default: 'sponsored nofollow',
		},
		target: {
			type: 'boolean',
			default: true,
		},
		styleLabel: {
			type: 'boolean',
			default: false,
		},
		zoomBtn: {
			type: 'boolean',
			default: false,
		},
		btnBorderRadius: {
			type: 'number',
			default: 4,
		},
	},
	/**
	 * @see ./edit.js
	 */
	edit: Edit,

	/**
	 * @see ./save.js
	 */
	save,
} );
