/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
import { InnerBlocks, RichText, useBlockProps } from '@wordpress/block-editor';

/**
 * The save function defines the way in which the different attributes should
 * be combined into the final markup, which is then serialized by the block
 * editor into `post_content`.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#save
 *
 * @return {WPElement} Element to render.
 */

export default function save( { attributes } ) {
	const blockProps = useBlockProps.save( {
		className: 'asl-product__row',
	} );

	const {
		number,
		heading,
		postList,
		label,
		btnText,
		link,
		rel,
		zoomBtn,
		target,
		btnBorderRadius,
		styleLabel,
		btnBackground,
		btnColor,
	} = attributes;
	return (
		<div { ...blockProps }>
			<div className="asl-product__column_0 asl-product__column">
				<RichText.Content
					tagName="p"
					value={ number }
					className="asl-table-number"
				/>
			</div>
			<div className="asl-product__column_1 asl-product__column">
				<InnerBlocks.Content />
			</div>
			<div className="asl-product__column_2 asl-product__column">
				<RichText.Content
					tagName="div"
					value={ label }
					className={
						styleLabel
							? 'asl-product__link-label asl-table-label'
							: 'asl-product__label asl-table-label'
					}
				/>

				<RichText.Content
					tagName="a"
					href={ link }
					target={ target ? '_blank' : '_self' }
					rel={ rel }
					value={ heading }
					className="asl-product-heading"
				/>
			</div>
			<div className="asl-product__column_3 asl-product__column">
				<RichText.Content
					tagName="ul"
					value={ postList }
					className="asl-product-table__list"
				/>
			</div>
			<div className="asl-product__column_4 asl-product__column">
				<span className={ zoomBtn ? 'btn-zoom start-zoom' : '' }>
					<RichText.Content
						tagName="a"
						value={ btnText }
						rel={ rel }
						href={ link }
						target={ target ? '_blank' : '_self' }
						className="asl-btn-pt"
						style={ {
							borderRadius: btnBorderRadius,
							color: btnColor,
							backgroundColor: btnBackground,
						} }
					/>
				</span>
			</div>
		</div>
	);
}
