/**
 * Registers a new block provided a unique name and an object defining its behavior.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-registration/
 */
import { registerBlockType } from '@wordpress/blocks';

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * All files containing `style` keyword are bundled together. The code used
 * gets applied both to the front of your site and to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import './style.scss';

/**
 * Internal dependencies
 */
import Edit from './edit';
import save from './save';

/**
 * Every block starts by registering a new block type definition.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-registration/
 */
registerBlockType( 'asl/product', {
	icon: {
		foreground: '#7e70af',
		src: (
			<svg xmlns="http://www.w3.org/2000/svg">
				<path d="M0 0h24v24H0V0z" fill="none" />
				<path d="M20 3H5c-1.1 0-2 .9-2 2v14c0 1.1.9 2 2 2h15c1.1 0 2-.9 2-2V5c0-1.1-.9-2-2-2zm0 2v3H5V5h15zm-5 14h-5v-9h5v9zM5 10h3v9H5v-9zm12 9v-9h3v9h-3z" />
			</svg>
		),
	},
	attributes: {
		template: {
			type: 'string',
			source: 'attribute',
			selector: '.asl-product',
			attribute: 'data-template',
			default: 't1',
		},
		count: {
			type: 'string',
			default: '',
			source: 'html',
			selector: '.asl-count',
		},
		label: {
			type: 'string',
			default: '',
			source: 'html',
			selector: '.asl-label',
		},
		title: {
			type: 'string',
			default: '',
			source: 'html',
			selector: '.asl-product__subheading',
		},
		secondTitle: {
			type: 'string',
			default: '',
			source: 'html',
			selector: '.asl-product__heading',
		},
		postContent: {
			type: 'array',
			source: 'children',
			selector: '.asl-product__description',
		},
		postList: {
			type: 'array',
			source: 'children',
			selector: '.asl-product__list',
		},
		link: {
			type: 'string',
			source: 'attribute',
			selector: 'a',
			attribute: 'href',
		},
		zoomBtn: {
			type: 'boolean',
			default: true,
		},
		animationBtn: {
			type: 'boolean',
			default: false,
		},
		target: {
			type: 'boolean',
			default: true,
		},
		twoComponent: {
			type: 'boolean',
			default: false,
		},
		rel: {
			type: 'string',
			source: 'attribute',
			selector: 'a',
			attribute: 'rel',
			default: 'sponsored nofollow',
		},
		btnBorderWidth: {
			type: 'number',
			default: 1,
		},
		btnBorderRadius: {
			type: 'number',
			default: 6,
		},
		btnText: {
			type: 'string',
			default: '',
			source: 'html',
			selector: '.asl-btn',
		},
		btnColor: {
			type: 'string',
			default: '#fff',
		},
		btnBackground: {
			type: 'string',
			default: '',
		},
		btnBorder: {
			type: 'string',
			default: 'transparent',
		},
	},

	/**
	 * @see ./edit.js
	 */
	edit: Edit,

	/**
	 * @see ./save.js
	 */
	save,
} );
